@@ -70,7 +70,11 @@ class WikiPush(object):
         if outputFormat.lower() == "csv":
             return self.convertToCSV(pageRecords)
         elif outputFormat.lower() == "json":
-            return json.dumps(pageRecords)
+            res = []
+            for page in pageRecords.values():
+                res.append(page)
+            res_json = json.dumps({"data": res}, default=str)
+            return res_json
         else:
             if self.debug:
                 print(f"Format {outputFormat} is not supported.")
@@ -372,10 +376,14 @@ class WikiPush(object):
         '''        
         for image in imageList:
             try:
-                self.log("%scopying image %s ..." % (delim,image.name), end='')  
+                self.log("%scopying image %s ..." % (delim,image.name), end='')
                 imagePath,filename=self.downloadImage(image);
-                description=image.imageinfo['comment'] 
-                self.uploadImage(imagePath,filename,description,ignore)
+                description=image.imageinfo['comment']
+                try:
+                    self.uploadImage(imagePath,filename,description,ignore)
+                    self.log("✅")
+                except Exception as ex:
+                    self.handleAPIWarnings(ex.args[0],ignoreExists=ignore)
                 if self.debug:
                     print(image.imageinfo)
             except Exception as ex:
@@ -407,7 +415,7 @@ class WikiPush(object):
         if warnings:
             for warning in warnings:
                 msg+="%s\n" % str(warning)
-        self.handleWarning(msg,ignoreExists)
+        self.handleWarning(msg,ignoreExists=ignoreExists)
         
     def handleWarning(self,msg,marker="⚠️",ignoreExists=False):
         '''
@@ -467,7 +475,8 @@ class WikiPush(object):
                 warnings=[]
                 for item in warningsDict.items():
                     warnings.append(str(item))
-            self.handleAPIWarnings(warnings,ignoreExists)
+            if warnings:
+                raise Exception(warnings)
 
     def restore(self, pageTitles=None, backupPath=None, listFile=None, stdIn=False):
         """
@@ -515,9 +524,9 @@ class WikiPush(object):
             except Exception as ex:
                 self.log("❌:%s" % str(ex) )
 
-__version__ = "0.3.11"
+__version__ = "0.3.12"
 __date__ = '2020-10-31'
-__updated__ = '2020-02-25'
+__updated__ = '2020-03-17'
 DEBUG=False
 
 def mainNuke(argv=None):
@@ -667,7 +676,7 @@ def main(argv=None,mode='wikipush'): # IGNORE:C0111
                 if mode=="wikiquery":
                     # we are finished
                     pass
-                if mode=="wikirestore":
+                elif mode=="wikirestore":
                     if args.pages is None and args.queryFile is None and args.query is None:
                         wikipush.restore(pageTitles=None,backupPath=args.backupPath,listFile=args.listFile)
                 else:
